@@ -12,11 +12,11 @@ IO::Die - Namespaced, error-checked I/O
 
 =head1 VERSION
 
-Version 0.053
+Version 0.054
 
 =cut
 
-our $VERSION = '0.053';
+our $VERSION = '0.054';
 
 #----------------------------------------------------------------------
 #PROTECTED
@@ -776,7 +776,7 @@ sub fcntl {
 
     local ( $!, $^E );
     my $ok = CORE::fcntl( $fh, $func, $scalar ) or do {
-        $NS->__THROW('Fcntl');
+        $NS->__THROW( 'Fcntl', function => $func, scalar => $scalar );
     };
 
     return $ok;
@@ -1213,7 +1213,7 @@ Additional attributes for each type are listed below.
 
 =item Exec              path, arguments
 
-=item Fcntl
+=item Fcntl             function, scalar
 
 =item FileOpen          mode, path; OPTIONAL: mask
 
